@@ -16,17 +16,17 @@ urlpatterns = [
     path(
         PYPI_API_URL + "pypi/<path:meta>/",
         MetadataView.as_view({"get": "retrieve"}),
-        name="pypi-metadata"
+        name="pypi-metadata",
     ),
     path(
         PYPI_API_URL + "simple/<str:package>/",
         SimpleView.as_view({"get": "retrieve"}),
-        name="simple-package-detail"
+        name="simple-package-detail",
     ),
     path(
-        PYPI_API_URL + 'simple/',
+        PYPI_API_URL + "simple/",
         SimpleView.as_view({"get": "list", "post": "create"}),
-        name="simple-detail"
+        name="simple-detail",
     ),
     path(PYPI_API_URL, PyPIView.as_view({"get": "retrieve"}), name="pypi-detail"),
 ]
